pub enum SymlinkPolicy {
Follow,
Skip,
}Expand description
Whether symlinked manifests and directories are resolved and walked into (issue #1112).
Variants
Follow
Symlinks are resolved and walked into.
Skip
Symlinks are detected but never resolved or descended into.