Output formatters for a crate::report::CheckReport (FR-006, FR-007).
Modules
- json
- Versioned JSON output (FR-007).
- sarif
- SARIF 2.1.0 output (FR-008, US-002) for GitHub code scanning and other SARIF consumers.
- table
- Human-readable table output (FR-006): findings grouped by file, then severity.
Enums
- DryRun
- Whether an
updaterun only previewed its plan without writing any change to disk.
Functions
- severity_
str - Renders
severityas the lowercase token used by both output formats.